Uses of Package org.openqa.selenium.server.log (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Package
org.openqa.selenium.server.log

Packages that use org.openqa.selenium.server.log
org.openqa.selenium.server.log |

Classes in org.openqa.selenium.server.log used by org.openqa.selenium.server.log
ShortTermMemoryHandler Handler who keeps in memory the last N records as is so that then can be retrieved "as is" on demand.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.